==> jc-1.4.0.tar.gz: java/rmi/MarshalledObject.h <==
// public final class java.rmi.MarshalledObject

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 498abb5de14ded5a java_rmi_MarshalledObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_MarshalledObject_H_
#define _JC_java_rmi_MarshalledObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_rmi_MarshalledObject$sub_refs	_jc_java_rmi_MarshalledObject$sub_refs;
typedef struct _jc_java_rmi_MarshalledObject$sub_nonrefs	_jc_java_rmi_MarshalledObject$sub_nonrefs;
typedef struct _jc_java_rmi_MarshalledObject$refs	_jc_java_rmi_MarshalledObject$refs;
typedef struct _jc_java_rmi_MarshalledObject$nonrefs	_jc_java_rmi_MarshalledObject$nonrefs;
typedef struct _jc_java_rmi_MarshalledObject$object	_jc_java_rmi_MarshalledObject$object;

typedef struct _jc_java_rmi_MarshalledObject$fields_struct	_jc_java_rmi_MarshalledObject$fields_struct;
typedef const struct _jc_java_rmi_MarshalledObject$vmethods	_jc_java_rmi_MarshalledObject$vmethods;
typedef const struct _jc_java_rmi_MarshalledObject$vtable	_jc_java_rmi_MarshalledObject$vtable;
typedef const struct _jc_java_rmi_MarshalledObject$vtype	_jc_java_rmi_MarshalledObject$vtype;

// Class fields structure
struct _jc_java_rmi_MarshalledObject$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_MarshalledObject$fields_struct _jc_java_rmi_MarshalledObject$class_fields;

// Constructors
extern void _jc_java_rmi_MarshalledObject$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_java_rmi_MarshalledObject$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_java_rmi_MarshalledObject$method$get$a27f05608bfbd09b(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *);
extern jint _jc_java_rmi_MarshalledObject$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_MarshalledObject$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_MarshalledObject$method_info$get$a27f05608bfbd09b;
extern _jc_method _jc_java_rmi_MarshalledObject$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_rmi_MarshalledObject$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*get$a27f05608bfbd09b)(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *);
};

// Vtable
struct _jc_java_rmi_MarshalledObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_MarshalledObject$vmethods	java_rmi_MarshalledObject;
};

// Vtype
struct _jc_java_rmi_MarshalledObject$vtype {
	_jc_type			type;
	_jc_java_rmi_MarshalledObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_MarshalledObject$sub_refs {
	_jc_byte_array	*objBytes;
	_jc_byte_array	*locBytes;
};

// Reference instance fields (object)
struct _jc_java_rmi_MarshalledObject$refs {
    _jc_java_rmi_MarshalledObject$sub_refs	java_rmi_MarshalledObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_MarshalledObject$sub_nonrefs {
	jint	hash;
};

// Non-reference instance fields (object)
struct _jc_java_rmi_MarshalledObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_MarshalledObject$sub_nonrefs	java_rmi_MarshalledObject;
};

// Object instance structure
struct _jc_java_rmi_MarshalledObject$object {
	_jc_java_rmi_MarshalledObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_MarshalledObject$vtype	*vtype;
	_jc_java_rmi_MarshalledObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_MarshalledObject$vtype _jc_java_rmi_MarshalledObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_MarshalledObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_MarshalledObject$class_object;

#endif	/* _JC_java_rmi_MarshalledObject_H_ */

==> jc-1.4.6.tar.gz: java/rmi/MarshalledObject.h <==
// public final class java.rmi.MarshalledObject

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 498abb5de14ded5a java_rmi_MarshalledObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_MarshalledObject_H_
#define _JC_java_rmi_MarshalledObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_rmi_MarshalledObject$sub_refs	_jc_java_rmi_MarshalledObject$sub_refs;
typedef struct _jc_java_rmi_MarshalledObject$sub_nonrefs	_jc_java_rmi_MarshalledObject$sub_nonrefs;
typedef struct _jc_java_rmi_MarshalledObject$refs	_jc_java_rmi_MarshalledObject$refs;
typedef struct _jc_java_rmi_MarshalledObject$nonrefs	_jc_java_rmi_MarshalledObject$nonrefs;
typedef struct _jc_java_rmi_MarshalledObject$object	_jc_java_rmi_MarshalledObject$object;

typedef struct _jc_java_rmi_MarshalledObject$fields_struct	_jc_java_rmi_MarshalledObject$fields_struct;
typedef const struct _jc_java_rmi_MarshalledObject$vmethods	_jc_java_rmi_MarshalledObject$vmethods;
typedef const struct _jc_java_rmi_MarshalledObject$vtable	_jc_java_rmi_MarshalledObject$vtable;
typedef const struct _jc_java_rmi_MarshalledObject$vtype	_jc_java_rmi_MarshalledObject$vtype;

// Class fields structure
struct _jc_java_rmi_MarshalledObject$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_MarshalledObject$fields_struct _jc_java_rmi_MarshalledObject$class_fields;

// Constructors
extern void _jc_java_rmi_MarshalledObject$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_rmi_MarshalledObject$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_rmi_MarshalledObject$method$get$a27f05608bfbd09b(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *) _JC_JCNI_ATTR;
extern jint _jc_java_rmi_MarshalledObject$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_MarshalledObject$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_MarshalledObject$method_info$get$a27f05608bfbd09b;
extern _jc_method _jc_java_rmi_MarshalledObject$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_rmi_MarshalledObject$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*get$a27f05608bfbd09b)(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_MarshalledObject$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_MarshalledObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_MarshalledObject$vmethods	java_rmi_MarshalledObject;
};

// Vtype
struct _jc_java_rmi_MarshalledObject$vtype {
	_jc_type			type;
	_jc_java_rmi_MarshalledObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_MarshalledObject$sub_refs {
	_jc_byte_array	*objBytes;
	_jc_byte_array	*locBytes;
};

// Reference instance fields (object)
struct _jc_java_rmi_MarshalledObject$refs {
    _jc_java_rmi_MarshalledObject$sub_refs	java_rmi_MarshalledObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_MarshalledObject$sub_nonrefs {
	jint	hash;
};

// Non-reference instance fields (object)
struct _jc_java_rmi_MarshalledObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_MarshalledObject$sub_nonrefs	java_rmi_MarshalledObject;
};

// Object instance structure
struct _jc_java_rmi_MarshalledObject$object {
	_jc_java_rmi_MarshalledObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_MarshalledObject$vtype	*vtype;
	_jc_java_rmi_MarshalledObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_MarshalledObject$vtype _jc_java_rmi_MarshalledObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_MarshalledObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_MarshalledObject$class_object;

#endif	/* _JC_java_rmi_MarshalledObject_H_ */
